.. module:: enaml.stdlib.dock_area_styles

=============================
enaml.stdlib.dock_area_styles
=============================

.. rubric:: Functions

.. autosummary::
    :nosignatures:

    available_styles
    register_styles
    get_registered_styles


.. rubric:: Classes

.. autosummary::
    :nosignatures:

    BasicStyle
    AreaStyle
    RubberBandStyle
    WindowStyle
    WindowButtonStyle
    ContainerStyle
    TabBarTabStyle
    TabBarCloseButtonStyle
    DockBarButtonStyle
    ItemStyle
    TitleBarStyle
    TitleBarLabelStyle
    TitleBarButtonStyle


.. autofunction:: available_styles

.. autofunction:: register_styles

.. autofunction:: get_registered_styles

.. autoclass:: BasicStyle

.. autoclass:: AreaStyle

.. autoclass:: RubberBandStyle

.. autoclass:: WindowStyle

.. autoclass:: WindowButtonStyle

.. autoclass:: ContainerStyle

.. autoclass:: TabBarTabStyle

.. autoclass:: TabBarCloseButtonStyle

.. autoclass:: DockBarButtonStyle

.. autoclass:: ItemStyle

.. autoclass:: TitleBarStyle

.. autoclass:: TitleBarLabelStyle

.. autoclass:: TitleBarButtonStyle
